
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.WebKit.Interfaces.DOMEventTarget
    ( 

-- * Exported types
    DOMEventTarget(..)                      ,
    noDOMEventTarget                        ,
    DOMEventTargetK                         ,
    toDOMEventTarget                        ,


 -- * Methods
-- ** dOMEventTargetAddEventListener
    dOMEventTargetAddEventListener          ,


-- ** dOMEventTargetDispatchEvent
    dOMEventTargetDispatchEvent             ,


-- ** dOMEventTargetRemoveEventListener
    dOMEventTargetRemoveEventListener       ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.WebKit.Types
import GI.WebKit.Callbacks
import qualified GI.GObject as GObject

-- interface DOMEventTarget 

newtype DOMEventTarget = DOMEventTarget (ForeignPtr DOMEventTarget)
noDOMEventTarget :: Maybe DOMEventTarget
noDOMEventTarget = Nothing

type instance AttributeList DOMEventTarget = DOMEventTargetAttributeList
type DOMEventTargetAttributeList = ('[ ] :: [(Symbol, *)])

type instance SignalList DOMEventTarget = DOMEventTargetSignalList
type DOMEventTargetSignalList = ('[ '("notify", GObject.ObjectNotifySignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

foreign import ccall "webkit_dom_event_target_get_type"
    c_webkit_dom_event_target_get_type :: IO GType

type instance ParentTypes DOMEventTarget = DOMEventTargetParentTypes
type DOMEventTargetParentTypes = '[GObject.Object]

instance GObject DOMEventTarget where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_webkit_dom_event_target_get_type
    

class GObject o => DOMEventTargetK o
instance (GObject o, IsDescendantOf DOMEventTarget o) => DOMEventTargetK o

toDOMEventTarget :: DOMEventTargetK o => o -> IO DOMEventTarget
toDOMEventTarget = unsafeCastTo DOMEventTarget

-- method DOMEventTarget::add_event_listener
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMEventTarget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "event_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "handler", argType = TInterface "GObject" "Closure", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "use_capture", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMEventTarget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "event_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "handler", argType = TInterface "GObject" "Closure", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "use_capture", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "webkit_dom_event_target_add_event_listener_with_closure" webkit_dom_event_target_add_event_listener_with_closure :: 
    Ptr DOMEventTarget ->                   -- _obj : TInterface "WebKit" "DOMEventTarget"
    CString ->                              -- event_name : TBasicType TUTF8
    Ptr Closure ->                          -- handler : TInterface "GObject" "Closure"
    CInt ->                                 -- use_capture : TBasicType TBoolean
    IO CInt


dOMEventTargetAddEventListener ::
    (MonadIO m, DOMEventTargetK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- event_name
    Closure ->                              -- handler
    Bool ->                                 -- use_capture
    m Bool
dOMEventTargetAddEventListener _obj event_name handler use_capture = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    event_name' <- textToCString event_name
    let handler' = unsafeManagedPtrGetPtr handler
    let use_capture' = (fromIntegral . fromEnum) use_capture
    result <- webkit_dom_event_target_add_event_listener_with_closure _obj' event_name' handler' use_capture'
    let result' = (/= 0) result
    touchManagedPtr _obj
    touchManagedPtr handler
    freeMem event_name'
    return result'

-- method DOMEventTarget::dispatch_event
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMEventTarget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "event", argType = TInterface "WebKit" "DOMEvent", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMEventTarget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "event", argType = TInterface "WebKit" "DOMEvent", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : True
-- Skip return : False

foreign import ccall "webkit_dom_event_target_dispatch_event" webkit_dom_event_target_dispatch_event :: 
    Ptr DOMEventTarget ->                   -- _obj : TInterface "WebKit" "DOMEventTarget"
    Ptr DOMEvent ->                         -- event : TInterface "WebKit" "DOMEvent"
    Ptr (Ptr GError) ->                     -- error
    IO CInt


dOMEventTargetDispatchEvent ::
    (MonadIO m, DOMEventTargetK a, DOMEventK b) =>
    a ->                                    -- _obj
    b ->                                    -- event
    m ()
dOMEventTargetDispatchEvent _obj event = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    let event' = unsafeManagedPtrCastPtr event
    onException (do
        _ <- propagateGError $ webkit_dom_event_target_dispatch_event _obj' event'
        touchManagedPtr _obj
        touchManagedPtr event
        return ()
     ) (do
        return ()
     )

-- method DOMEventTarget::remove_event_listener
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMEventTarget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "event_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "handler", argType = TInterface "GObject" "Closure", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "use_capture", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMEventTarget", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "event_name", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "handler", argType = TInterface "GObject" "Closure", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "use_capture", argType = TBasicType TBoolean, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TBoolean
-- throws : False
-- Skip return : False

foreign import ccall "webkit_dom_event_target_remove_event_listener_with_closure" webkit_dom_event_target_remove_event_listener_with_closure :: 
    Ptr DOMEventTarget ->                   -- _obj : TInterface "WebKit" "DOMEventTarget"
    CString ->                              -- event_name : TBasicType TUTF8
    Ptr Closure ->                          -- handler : TInterface "GObject" "Closure"
    CInt ->                                 -- use_capture : TBasicType TBoolean
    IO CInt


dOMEventTargetRemoveEventListener ::
    (MonadIO m, DOMEventTargetK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- event_name
    Closure ->                              -- handler
    Bool ->                                 -- use_capture
    m Bool
dOMEventTargetRemoveEventListener _obj event_name handler use_capture = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    event_name' <- textToCString event_name
    let handler' = unsafeManagedPtrGetPtr handler
    let use_capture' = (fromIntegral . fromEnum) use_capture
    result <- webkit_dom_event_target_remove_event_listener_with_closure _obj' event_name' handler' use_capture'
    let result' = (/= 0) result
    touchManagedPtr _obj
    touchManagedPtr handler
    freeMem event_name'
    return result'


