
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.WebKit.Objects.DOMHTMLMapElement
    ( 

-- * Exported types
    DOMHTMLMapElement(..)                   ,
    DOMHTMLMapElementK                      ,
    toDOMHTMLMapElement                     ,
    noDOMHTMLMapElement                     ,


 -- * Methods
-- ** dOMHTMLMapElementGetAreas
    dOMHTMLMapElementGetAreas               ,


-- ** dOMHTMLMapElementGetName
    dOMHTMLMapElementGetName                ,


-- ** dOMHTMLMapElementSetName
    dOMHTMLMapElementSetName                ,




 -- * Properties
-- ** Areas
    DOMHTMLMapElementAreasPropertyInfo      ,
    getDOMHTMLMapElementAreas               ,


-- ** Name
    DOMHTMLMapElementNamePropertyInfo       ,
    constructDOMHTMLMapElementName          ,
    getDOMHTMLMapElementName                ,
    setDOMHTMLMapElementName                ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.WebKit.Types
import GI.WebKit.Callbacks
import qualified GI.GObject as GObject

newtype DOMHTMLMapElement = DOMHTMLMapElement (ForeignPtr DOMHTMLMapElement)
foreign import ccall "webkit_dom_html_map_element_get_type"
    c_webkit_dom_html_map_element_get_type :: IO GType

type instance ParentTypes DOMHTMLMapElement = DOMHTMLMapElementParentTypes
type DOMHTMLMapElementParentTypes = '[DOMHTMLElement, DOMElement, DOMNode, DOMObject, GObject.Object, DOMEventTarget]

instance GObject DOMHTMLMapElement where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_webkit_dom_html_map_element_get_type
    

class GObject o => DOMHTMLMapElementK o
instance (GObject o, IsDescendantOf DOMHTMLMapElement o) => DOMHTMLMapElementK o

toDOMHTMLMapElement :: DOMHTMLMapElementK o => o -> IO DOMHTMLMapElement
toDOMHTMLMapElement = unsafeCastTo DOMHTMLMapElement

noDOMHTMLMapElement :: Maybe DOMHTMLMapElement
noDOMHTMLMapElement = Nothing

-- VVV Prop "areas"
   -- Type: TInterface "WebKit" "DOMHTMLCollection"
   -- Flags: [PropertyReadable]

getDOMHTMLMapElementAreas :: (MonadIO m, DOMHTMLMapElementK o) => o -> m DOMHTMLCollection
getDOMHTMLMapElementAreas obj = liftIO $ getObjectPropertyObject obj "areas" DOMHTMLCollection

data DOMHTMLMapElementAreasPropertyInfo
instance AttrInfo DOMHTMLMapElementAreasPropertyInfo where
    type AttrAllowedOps DOMHTMLMapElementAreasPropertyInfo = '[ 'AttrGet]
    type AttrSetTypeConstraint DOMHTMLMapElementAreasPropertyInfo = (~) ()
    type AttrBaseTypeConstraint DOMHTMLMapElementAreasPropertyInfo = DOMHTMLMapElementK
    type AttrGetType DOMHTMLMapElementAreasPropertyInfo = DOMHTMLCollection
    type AttrLabel DOMHTMLMapElementAreasPropertyInfo = "DOMHTMLMapElement::areas"
    attrGet _ = getDOMHTMLMapElementAreas
    attrSet _ = undefined
    attrConstruct _ = undefined

-- VVV Prop "name"
   -- Type: TBasicType TUTF8
   -- Flags: [PropertyReadable,PropertyWritable]

getDOMHTMLMapElementName :: (MonadIO m, DOMHTMLMapElementK o) => o -> m T.Text
getDOMHTMLMapElementName obj = liftIO $ getObjectPropertyString obj "name"

setDOMHTMLMapElementName :: (MonadIO m, DOMHTMLMapElementK o) => o -> T.Text -> m ()
setDOMHTMLMapElementName obj val = liftIO $ setObjectPropertyString obj "name" val

constructDOMHTMLMapElementName :: T.Text -> IO ([Char], GValue)
constructDOMHTMLMapElementName val = constructObjectPropertyString "name" val

data DOMHTMLMapElementNamePropertyInfo
instance AttrInfo DOMHTMLMapElementNamePropertyInfo where
    type AttrAllowedOps DOMHTMLMapElementNamePropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint DOMHTMLMapElementNamePropertyInfo = (~) T.Text
    type AttrBaseTypeConstraint DOMHTMLMapElementNamePropertyInfo = DOMHTMLMapElementK
    type AttrGetType DOMHTMLMapElementNamePropertyInfo = T.Text
    type AttrLabel DOMHTMLMapElementNamePropertyInfo = "DOMHTMLMapElement::name"
    attrGet _ = getDOMHTMLMapElementName
    attrSet _ = setDOMHTMLMapElementName
    attrConstruct _ = constructDOMHTMLMapElementName

type instance AttributeList DOMHTMLMapElement = DOMHTMLMapElementAttributeList
type DOMHTMLMapElementAttributeList = ('[ '("access-key", DOMHTMLElementAccessKeyPropertyInfo), '("areas", DOMHTMLMapElementAreasPropertyInfo), '("attributes", DOMElementAttributesPropertyInfo), '("base-uri", DOMNodeBaseUriPropertyInfo), '("child-element-count", DOMElementChildElementCountPropertyInfo), '("child-nodes", DOMNodeChildNodesPropertyInfo), '("children", DOMHTMLElementChildrenPropertyInfo), '("class-list", DOMElementClassListPropertyInfo), '("class-name", DOMElementClassNamePropertyInfo), '("client-height", DOMElementClientHeightPropertyInfo), '("client-left", DOMElementClientLeftPropertyInfo), '("client-top", DOMElementClientTopPropertyInfo), '("client-width", DOMElementClientWidthPropertyInfo), '("content-editable", DOMHTMLElementContentEditablePropertyInfo), '("core-object", DOMObjectCoreObjectPropertyInfo), '("dir", DOMHTMLElementDirPropertyInfo), '("draggable", DOMHTMLElementDraggablePropertyInfo), '("first-child", DOMNodeFirstChildPropertyInfo), '("first-element-child", DOMElementFirstElementChildPropertyInfo), '("hidden", DOMHTMLElementHiddenPropertyInfo), '("id", DOMElementIdPropertyInfo), '("inner-html", DOMHTMLElementInnerHtmlPropertyInfo), '("inner-text", DOMHTMLElementInnerTextPropertyInfo), '("is-content-editable", DOMHTMLElementIsContentEditablePropertyInfo), '("lang", DOMHTMLElementLangPropertyInfo), '("last-child", DOMNodeLastChildPropertyInfo), '("last-element-child", DOMElementLastElementChildPropertyInfo), '("local-name", DOMNodeLocalNamePropertyInfo), '("name", DOMHTMLMapElementNamePropertyInfo), '("namespace-uri", DOMNodeNamespaceUriPropertyInfo), '("next-element-sibling", DOMElementNextElementSiblingPropertyInfo), '("next-sibling", DOMNodeNextSiblingPropertyInfo), '("node-name", DOMNodeNodeNamePropertyInfo), '("node-type", DOMNodeNodeTypePropertyInfo), '("node-value", DOMNodeNodeValuePropertyInfo), '("offset-height", DOMElementOffsetHeightPropertyInfo), '("offset-left", DOMElementOffsetLeftPropertyInfo), '("offset-parent", DOMElementOffsetParentPropertyInfo), '("offset-top", DOMElementOffsetTopPropertyInfo), '("offset-width", DOMElementOffsetWidthPropertyInfo), '("outer-html", DOMHTMLElementOuterHtmlPropertyInfo), '("outer-text", DOMHTMLElementOuterTextPropertyInfo), '("owner-document", DOMNodeOwnerDocumentPropertyInfo), '("parent-element", DOMNodeParentElementPropertyInfo), '("parent-node", DOMNodeParentNodePropertyInfo), '("prefix", DOMNodePrefixPropertyInfo), '("previous-element-sibling", DOMElementPreviousElementSiblingPropertyInfo), '("previous-sibling", DOMNodePreviousSiblingPropertyInfo), '("scroll-height", DOMElementScrollHeightPropertyInfo), '("scroll-left", DOMElementScrollLeftPropertyInfo), '("scroll-top", DOMElementScrollTopPropertyInfo), '("scroll-width", DOMElementScrollWidthPropertyInfo), '("spellcheck", DOMHTMLElementSpellcheckPropertyInfo), '("style", DOMElementStylePropertyInfo), '("tab-index", DOMHTMLElementTabIndexPropertyInfo), '("tag-name", DOMElementTagNamePropertyInfo), '("text-content", DOMNodeTextContentPropertyInfo), '("title", DOMHTMLElementTitlePropertyInfo), '("translate", DOMHTMLElementTranslatePropertyInfo), '("webkit-region-overset", DOMElementWebkitRegionOversetPropertyInfo), '("webkitdropzone", DOMHTMLElementWebkitdropzonePropertyInfo)] :: [(Symbol, *)])

type instance SignalList DOMHTMLMapElement = DOMHTMLMapElementSignalList
type DOMHTMLMapElementSignalList = ('[ '("notify", GObject.ObjectNotifySignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method DOMHTMLMapElement::get_areas
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMHTMLMapElement", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMHTMLMapElement", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "WebKit" "DOMHTMLCollection"
-- throws : False
-- Skip return : False

foreign import ccall "webkit_dom_html_map_element_get_areas" webkit_dom_html_map_element_get_areas :: 
    Ptr DOMHTMLMapElement ->                -- _obj : TInterface "WebKit" "DOMHTMLMapElement"
    IO (Ptr DOMHTMLCollection)


dOMHTMLMapElementGetAreas ::
    (MonadIO m, DOMHTMLMapElementK a) =>
    a ->                                    -- _obj
    m DOMHTMLCollection
dOMHTMLMapElementGetAreas _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- webkit_dom_html_map_element_get_areas _obj'
    checkUnexpectedReturnNULL "webkit_dom_html_map_element_get_areas" result
    result' <- (wrapObject DOMHTMLCollection) result
    touchManagedPtr _obj
    return result'

-- method DOMHTMLMapElement::get_name
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMHTMLMapElement", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMHTMLMapElement", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUTF8
-- throws : False
-- Skip return : False

foreign import ccall "webkit_dom_html_map_element_get_name" webkit_dom_html_map_element_get_name :: 
    Ptr DOMHTMLMapElement ->                -- _obj : TInterface "WebKit" "DOMHTMLMapElement"
    IO CString


dOMHTMLMapElementGetName ::
    (MonadIO m, DOMHTMLMapElementK a) =>
    a ->                                    -- _obj
    m T.Text
dOMHTMLMapElementGetName _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- webkit_dom_html_map_element_get_name _obj'
    checkUnexpectedReturnNULL "webkit_dom_html_map_element_get_name" result
    result' <- cstringToText result
    freeMem result
    touchManagedPtr _obj
    return result'

-- method DOMHTMLMapElement::set_name
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMHTMLMapElement", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "value", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "DOMHTMLMapElement", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "value", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_dom_html_map_element_set_name" webkit_dom_html_map_element_set_name :: 
    Ptr DOMHTMLMapElement ->                -- _obj : TInterface "WebKit" "DOMHTMLMapElement"
    CString ->                              -- value : TBasicType TUTF8
    IO ()


dOMHTMLMapElementSetName ::
    (MonadIO m, DOMHTMLMapElementK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- value
    m ()
dOMHTMLMapElementSetName _obj value = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    value' <- textToCString value
    webkit_dom_html_map_element_set_name _obj' value'
    touchManagedPtr _obj
    freeMem value'
    return ()


