
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.WebKit.Objects.IconDatabase
    ( 

-- * Exported types
    IconDatabase(..)                        ,
    IconDatabaseK                           ,
    toIconDatabase                          ,
    noIconDatabase                          ,


 -- * Methods
-- ** iconDatabaseClear
    iconDatabaseClear                       ,


-- ** iconDatabaseGetIconPixbuf
    iconDatabaseGetIconPixbuf               ,


-- ** iconDatabaseGetIconUri
    iconDatabaseGetIconUri                  ,


-- ** iconDatabaseGetPath
    iconDatabaseGetPath                     ,


-- ** iconDatabaseSetPath
    iconDatabaseSetPath                     ,




 -- * Properties
-- ** Path
    IconDatabasePathPropertyInfo            ,
    constructIconDatabasePath               ,
    getIconDatabasePath                     ,
    setIconDatabasePath                     ,




 -- * Signals
-- ** IconLoaded
    IconDatabaseIconLoadedCallback          ,
    IconDatabaseIconLoadedCallbackC         ,
    IconDatabaseIconLoadedSignalInfo        ,
    afterIconDatabaseIconLoaded             ,
    iconDatabaseIconLoadedCallbackWrapper   ,
    iconDatabaseIconLoadedClosure           ,
    mkIconDatabaseIconLoadedCallback        ,
    noIconDatabaseIconLoadedCallback        ,
    onIconDatabaseIconLoaded                ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.WebKit.Types
import GI.WebKit.Callbacks
import qualified GI.GObject as GObject
import qualified GI.GdkPixbuf as GdkPixbuf

newtype IconDatabase = IconDatabase (ForeignPtr IconDatabase)
foreign import ccall "webkit_icon_database_get_type"
    c_webkit_icon_database_get_type :: IO GType

type instance ParentTypes IconDatabase = IconDatabaseParentTypes
type IconDatabaseParentTypes = '[GObject.Object]

instance GObject IconDatabase where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_webkit_icon_database_get_type
    

class GObject o => IconDatabaseK o
instance (GObject o, IsDescendantOf IconDatabase o) => IconDatabaseK o

toIconDatabase :: IconDatabaseK o => o -> IO IconDatabase
toIconDatabase = unsafeCastTo IconDatabase

noIconDatabase :: Maybe IconDatabase
noIconDatabase = Nothing

-- signal IconDatabase::icon-loaded
type IconDatabaseIconLoadedCallback =
    WebFrame ->
    T.Text ->
    IO ()

noIconDatabaseIconLoadedCallback :: Maybe IconDatabaseIconLoadedCallback
noIconDatabaseIconLoadedCallback = Nothing

type IconDatabaseIconLoadedCallbackC =
    Ptr () ->                               -- object
    Ptr WebFrame ->
    CString ->
    Ptr () ->                               -- user_data
    IO ()

foreign import ccall "wrapper"
    mkIconDatabaseIconLoadedCallback :: IconDatabaseIconLoadedCallbackC -> IO (FunPtr IconDatabaseIconLoadedCallbackC)

iconDatabaseIconLoadedClosure :: IconDatabaseIconLoadedCallback -> IO Closure
iconDatabaseIconLoadedClosure cb = newCClosure =<< mkIconDatabaseIconLoadedCallback wrapped
    where wrapped = iconDatabaseIconLoadedCallbackWrapper cb

iconDatabaseIconLoadedCallbackWrapper ::
    IconDatabaseIconLoadedCallback ->
    Ptr () ->
    Ptr WebFrame ->
    CString ->
    Ptr () ->
    IO ()
iconDatabaseIconLoadedCallbackWrapper _cb _ frame frame_uri _ = do
    frame' <- (newObject WebFrame) frame
    frame_uri' <- cstringToText frame_uri
    _cb  frame' frame_uri'

onIconDatabaseIconLoaded :: (GObject a, MonadIO m) => a -> IconDatabaseIconLoadedCallback -> m SignalHandlerId
onIconDatabaseIconLoaded obj cb = liftIO $ connectIconDatabaseIconLoaded obj cb SignalConnectBefore
afterIconDatabaseIconLoaded :: (GObject a, MonadIO m) => a -> IconDatabaseIconLoadedCallback -> m SignalHandlerId
afterIconDatabaseIconLoaded obj cb = connectIconDatabaseIconLoaded obj cb SignalConnectAfter

connectIconDatabaseIconLoaded :: (GObject a, MonadIO m) =>
                                 a -> IconDatabaseIconLoadedCallback -> SignalConnectMode -> m SignalHandlerId
connectIconDatabaseIconLoaded obj cb after = liftIO $ do
    cb' <- mkIconDatabaseIconLoadedCallback (iconDatabaseIconLoadedCallbackWrapper cb)
    connectSignalFunPtr obj "icon-loaded" cb' after

-- VVV Prop "path"
   -- Type: TBasicType TUTF8
   -- Flags: [PropertyReadable,PropertyWritable]

getIconDatabasePath :: (MonadIO m, IconDatabaseK o) => o -> m T.Text
getIconDatabasePath obj = liftIO $ getObjectPropertyString obj "path"

setIconDatabasePath :: (MonadIO m, IconDatabaseK o) => o -> T.Text -> m ()
setIconDatabasePath obj val = liftIO $ setObjectPropertyString obj "path" val

constructIconDatabasePath :: T.Text -> IO ([Char], GValue)
constructIconDatabasePath val = constructObjectPropertyString "path" val

data IconDatabasePathPropertyInfo
instance AttrInfo IconDatabasePathPropertyInfo where
    type AttrAllowedOps IconDatabasePathPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint IconDatabasePathPropertyInfo = (~) T.Text
    type AttrBaseTypeConstraint IconDatabasePathPropertyInfo = IconDatabaseK
    type AttrGetType IconDatabasePathPropertyInfo = T.Text
    type AttrLabel IconDatabasePathPropertyInfo = "IconDatabase::path"
    attrGet _ = getIconDatabasePath
    attrSet _ = setIconDatabasePath
    attrConstruct _ = constructIconDatabasePath

type instance AttributeList IconDatabase = IconDatabaseAttributeList
type IconDatabaseAttributeList = ('[ '("path", IconDatabasePathPropertyInfo)] :: [(Symbol, *)])

data IconDatabaseIconLoadedSignalInfo
instance SignalInfo IconDatabaseIconLoadedSignalInfo where
    type HaskellCallbackType IconDatabaseIconLoadedSignalInfo = IconDatabaseIconLoadedCallback
    connectSignal _ = connectIconDatabaseIconLoaded

type instance SignalList IconDatabase = IconDatabaseSignalList
type IconDatabaseSignalList = ('[ '("icon-loaded", IconDatabaseIconLoadedSignalInfo), '("notify", GObject.ObjectNotifySignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method IconDatabase::clear
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_icon_database_clear" webkit_icon_database_clear :: 
    Ptr IconDatabase ->                     -- _obj : TInterface "WebKit" "IconDatabase"
    IO ()

{-# DEPRECATED iconDatabaseClear ["(Since version 1.8)","Use webkit_favicon_database_clear() instead."]#-}
iconDatabaseClear ::
    (MonadIO m, IconDatabaseK a) =>
    a ->                                    -- _obj
    m ()
iconDatabaseClear _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    webkit_icon_database_clear _obj'
    touchManagedPtr _obj
    return ()

-- method IconDatabase::get_icon_pixbuf
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "page_uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "page_uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "GdkPixbuf" "Pixbuf"
-- throws : False
-- Skip return : False

foreign import ccall "webkit_icon_database_get_icon_pixbuf" webkit_icon_database_get_icon_pixbuf :: 
    Ptr IconDatabase ->                     -- _obj : TInterface "WebKit" "IconDatabase"
    CString ->                              -- page_uri : TBasicType TUTF8
    IO (Ptr GdkPixbuf.Pixbuf)

{-# DEPRECATED iconDatabaseGetIconPixbuf ["(Since version 1.8)","Use webkit_favicon_database_try_get_favicon_pixbuf() instead."]#-}
iconDatabaseGetIconPixbuf ::
    (MonadIO m, IconDatabaseK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- page_uri
    m GdkPixbuf.Pixbuf
iconDatabaseGetIconPixbuf _obj page_uri = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    page_uri' <- textToCString page_uri
    result <- webkit_icon_database_get_icon_pixbuf _obj' page_uri'
    checkUnexpectedReturnNULL "webkit_icon_database_get_icon_pixbuf" result
    result' <- (wrapObject GdkPixbuf.Pixbuf) result
    touchManagedPtr _obj
    freeMem page_uri'
    return result'

-- method IconDatabase::get_icon_uri
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "page_uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "page_uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUTF8
-- throws : False
-- Skip return : False

foreign import ccall "webkit_icon_database_get_icon_uri" webkit_icon_database_get_icon_uri :: 
    Ptr IconDatabase ->                     -- _obj : TInterface "WebKit" "IconDatabase"
    CString ->                              -- page_uri : TBasicType TUTF8
    IO CString

{-# DEPRECATED iconDatabaseGetIconUri ["(Since version 1.8)","Use webkit_favicon_database_get_favicon_uri() instead."]#-}
iconDatabaseGetIconUri ::
    (MonadIO m, IconDatabaseK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- page_uri
    m T.Text
iconDatabaseGetIconUri _obj page_uri = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    page_uri' <- textToCString page_uri
    result <- webkit_icon_database_get_icon_uri _obj' page_uri'
    checkUnexpectedReturnNULL "webkit_icon_database_get_icon_uri" result
    result' <- cstringToText result
    freeMem result
    touchManagedPtr _obj
    freeMem page_uri'
    return result'

-- method IconDatabase::get_path
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUTF8
-- throws : False
-- Skip return : False

foreign import ccall "webkit_icon_database_get_path" webkit_icon_database_get_path :: 
    Ptr IconDatabase ->                     -- _obj : TInterface "WebKit" "IconDatabase"
    IO CString

{-# DEPRECATED iconDatabaseGetPath ["(Since version 1.8)","Use webkit_favicon_database_get_path() instead."]#-}
iconDatabaseGetPath ::
    (MonadIO m, IconDatabaseK a) =>
    a ->                                    -- _obj
    m T.Text
iconDatabaseGetPath _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- webkit_icon_database_get_path _obj'
    checkUnexpectedReturnNULL "webkit_icon_database_get_path" result
    result' <- cstringToText result
    touchManagedPtr _obj
    return result'

-- method IconDatabase::set_path
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "path", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "IconDatabase", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "path", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_icon_database_set_path" webkit_icon_database_set_path :: 
    Ptr IconDatabase ->                     -- _obj : TInterface "WebKit" "IconDatabase"
    CString ->                              -- path : TBasicType TUTF8
    IO ()

{-# DEPRECATED iconDatabaseSetPath ["(Since version 1.8)","Use webkit_favicon_database_set_path() instead."]#-}
iconDatabaseSetPath ::
    (MonadIO m, IconDatabaseK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- path
    m ()
iconDatabaseSetPath _obj path = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    path' <- textToCString path
    webkit_icon_database_set_path _obj' path'
    touchManagedPtr _obj
    freeMem path'
    return ()


