
{- |
Copyright  : Will Thompson, Iñaki García Etxebarria and Jonas Platte
License    : LGPL-2.1
Maintainer : Iñaki García Etxebarria (garetxe@gmail.com)
-}

module GI.WebKit.Objects.NetworkRequest
    ( 

-- * Exported types
    NetworkRequest(..)                      ,
    NetworkRequestK                         ,
    toNetworkRequest                        ,
    noNetworkRequest                        ,


 -- * Methods
-- ** networkRequestGetMessage
    networkRequestGetMessage                ,


-- ** networkRequestGetUri
    networkRequestGetUri                    ,


-- ** networkRequestNew
    networkRequestNew                       ,


-- ** networkRequestSetUri
    networkRequestSetUri                    ,




 -- * Properties
-- ** Message
    NetworkRequestMessagePropertyInfo       ,
    constructNetworkRequestMessage          ,
    getNetworkRequestMessage                ,


-- ** Uri
    NetworkRequestUriPropertyInfo           ,
    constructNetworkRequestUri              ,
    getNetworkRequestUri                    ,
    setNetworkRequestUri                    ,




    ) where

import Prelude ()
import Data.GI.Base.ShortPrelude

import qualified Data.Text as T
import qualified Data.ByteString.Char8 as B
import qualified Data.Map as Map

import GI.WebKit.Types
import GI.WebKit.Callbacks
import qualified GI.GObject as GObject
import qualified GI.Soup as Soup

newtype NetworkRequest = NetworkRequest (ForeignPtr NetworkRequest)
foreign import ccall "webkit_network_request_get_type"
    c_webkit_network_request_get_type :: IO GType

type instance ParentTypes NetworkRequest = NetworkRequestParentTypes
type NetworkRequestParentTypes = '[GObject.Object]

instance GObject NetworkRequest where
    gobjectIsInitiallyUnowned _ = False
    gobjectType _ = c_webkit_network_request_get_type
    

class GObject o => NetworkRequestK o
instance (GObject o, IsDescendantOf NetworkRequest o) => NetworkRequestK o

toNetworkRequest :: NetworkRequestK o => o -> IO NetworkRequest
toNetworkRequest = unsafeCastTo NetworkRequest

noNetworkRequest :: Maybe NetworkRequest
noNetworkRequest = Nothing

-- VVV Prop "message"
   -- Type: TInterface "Soup" "Message"
   -- Flags: [PropertyReadable,PropertyWritable,PropertyConstructOnly]

getNetworkRequestMessage :: (MonadIO m, NetworkRequestK o) => o -> m Soup.Message
getNetworkRequestMessage obj = liftIO $ getObjectPropertyObject obj "message" Soup.Message

constructNetworkRequestMessage :: (Soup.MessageK a) => a -> IO ([Char], GValue)
constructNetworkRequestMessage val = constructObjectPropertyObject "message" val

data NetworkRequestMessagePropertyInfo
instance AttrInfo NetworkRequestMessagePropertyInfo where
    type AttrAllowedOps NetworkRequestMessagePropertyInfo = '[ 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint NetworkRequestMessagePropertyInfo = Soup.MessageK
    type AttrBaseTypeConstraint NetworkRequestMessagePropertyInfo = NetworkRequestK
    type AttrGetType NetworkRequestMessagePropertyInfo = Soup.Message
    type AttrLabel NetworkRequestMessagePropertyInfo = "NetworkRequest::message"
    attrGet _ = getNetworkRequestMessage
    attrSet _ = undefined
    attrConstruct _ = constructNetworkRequestMessage

-- VVV Prop "uri"
   -- Type: TBasicType TUTF8
   -- Flags: [PropertyReadable,PropertyWritable]

getNetworkRequestUri :: (MonadIO m, NetworkRequestK o) => o -> m T.Text
getNetworkRequestUri obj = liftIO $ getObjectPropertyString obj "uri"

setNetworkRequestUri :: (MonadIO m, NetworkRequestK o) => o -> T.Text -> m ()
setNetworkRequestUri obj val = liftIO $ setObjectPropertyString obj "uri" val

constructNetworkRequestUri :: T.Text -> IO ([Char], GValue)
constructNetworkRequestUri val = constructObjectPropertyString "uri" val

data NetworkRequestUriPropertyInfo
instance AttrInfo NetworkRequestUriPropertyInfo where
    type AttrAllowedOps NetworkRequestUriPropertyInfo = '[ 'AttrSet, 'AttrConstruct, 'AttrGet]
    type AttrSetTypeConstraint NetworkRequestUriPropertyInfo = (~) T.Text
    type AttrBaseTypeConstraint NetworkRequestUriPropertyInfo = NetworkRequestK
    type AttrGetType NetworkRequestUriPropertyInfo = T.Text
    type AttrLabel NetworkRequestUriPropertyInfo = "NetworkRequest::uri"
    attrGet _ = getNetworkRequestUri
    attrSet _ = setNetworkRequestUri
    attrConstruct _ = constructNetworkRequestUri

type instance AttributeList NetworkRequest = NetworkRequestAttributeList
type NetworkRequestAttributeList = ('[ '("message", NetworkRequestMessagePropertyInfo), '("uri", NetworkRequestUriPropertyInfo)] :: [(Symbol, *)])

type instance SignalList NetworkRequest = NetworkRequestSignalList
type NetworkRequestSignalList = ('[ '("notify", GObject.ObjectNotifySignalInfo), '("notify::[property]", GObjectNotifySignalInfo)] :: [(Symbol, *)])

-- method NetworkRequest::new
-- method type : Constructor
-- Args : [Arg {argName = "uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "WebKit" "NetworkRequest"
-- throws : False
-- Skip return : False

foreign import ccall "webkit_network_request_new" webkit_network_request_new :: 
    CString ->                              -- uri : TBasicType TUTF8
    IO (Ptr NetworkRequest)


networkRequestNew ::
    (MonadIO m) =>
    T.Text ->                               -- uri
    m NetworkRequest
networkRequestNew uri = liftIO $ do
    uri' <- textToCString uri
    result <- webkit_network_request_new uri'
    checkUnexpectedReturnNULL "webkit_network_request_new" result
    result' <- (wrapObject NetworkRequest) result
    freeMem uri'
    return result'

-- method NetworkRequest::get_message
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "NetworkRequest", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "NetworkRequest", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TInterface "Soup" "Message"
-- throws : False
-- Skip return : False

foreign import ccall "webkit_network_request_get_message" webkit_network_request_get_message :: 
    Ptr NetworkRequest ->                   -- _obj : TInterface "WebKit" "NetworkRequest"
    IO (Ptr Soup.Message)


networkRequestGetMessage ::
    (MonadIO m, NetworkRequestK a) =>
    a ->                                    -- _obj
    m Soup.Message
networkRequestGetMessage _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- webkit_network_request_get_message _obj'
    checkUnexpectedReturnNULL "webkit_network_request_get_message" result
    result' <- (newObject Soup.Message) result
    touchManagedPtr _obj
    return result'

-- method NetworkRequest::get_uri
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "NetworkRequest", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "NetworkRequest", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TUTF8
-- throws : False
-- Skip return : False

foreign import ccall "webkit_network_request_get_uri" webkit_network_request_get_uri :: 
    Ptr NetworkRequest ->                   -- _obj : TInterface "WebKit" "NetworkRequest"
    IO CString


networkRequestGetUri ::
    (MonadIO m, NetworkRequestK a) =>
    a ->                                    -- _obj
    m T.Text
networkRequestGetUri _obj = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    result <- webkit_network_request_get_uri _obj'
    checkUnexpectedReturnNULL "webkit_network_request_get_uri" result
    result' <- cstringToText result
    touchManagedPtr _obj
    return result'

-- method NetworkRequest::set_uri
-- method type : OrdinaryMethod
-- Args : [Arg {argName = "_obj", argType = TInterface "WebKit" "NetworkRequest", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- Lengths : []
-- hInArgs : [Arg {argName = "_obj", argType = TInterface "WebKit" "NetworkRequest", direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing},Arg {argName = "uri", argType = TBasicType TUTF8, direction = DirectionIn, mayBeNull = False, argScope = ScopeTypeInvalid, argClosure = -1, argDestroy = -1, transfer = TransferNothing}]
-- returnType : TBasicType TVoid
-- throws : False
-- Skip return : False

foreign import ccall "webkit_network_request_set_uri" webkit_network_request_set_uri :: 
    Ptr NetworkRequest ->                   -- _obj : TInterface "WebKit" "NetworkRequest"
    CString ->                              -- uri : TBasicType TUTF8
    IO ()


networkRequestSetUri ::
    (MonadIO m, NetworkRequestK a) =>
    a ->                                    -- _obj
    T.Text ->                               -- uri
    m ()
networkRequestSetUri _obj uri = liftIO $ do
    let _obj' = unsafeManagedPtrCastPtr _obj
    uri' <- textToCString uri
    webkit_network_request_set_uri _obj' uri'
    touchManagedPtr _obj
    freeMem uri'
    return ()


